==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/content/fluids/pipes/valve/FluidValveBlock.java <==
package com.zurrtum.create.content.fluids.pipes.valve;

import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.AllShapes;
import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.content.fluids.FluidPropagator;
import com.zurrtum.create.content.fluids.pipes.FluidPipeBlock;
import com.zurrtum.create.content.fluids.pipes.IAxisPipe;
import com.zurrtum.create.content.kinetics.base.DirectionalAxisKineticBlock;
import com.zurrtum.create.foundation.block.IBE;
import com.zurrtum.create.foundation.block.NeighborUpdateListeningBlock;
import com.zurrtum.create.foundation.block.ProperWaterloggedBlock;
import net.minecraft.class_10;
import net.minecraft.class_10225;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_1953;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_2746;
import net.minecraft.class_3218;
import net.minecraft.class_3610;
import net.minecraft.class_3726;
import net.minecraft.class_4209;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_9904;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class FluidValveBlock extends DirectionalAxisKineticBlock implements IAxisPipe, IBE<FluidValveBlockEntity>, ProperWaterloggedBlock, NeighborUpdateListeningBlock {

    public static final class_2746 ENABLED = class_2746.method_11825("enabled");

    public FluidValveBlock(class_2251 properties) {
        super(properties);
        method_9590(method_9564().method_11657(ENABLED, false).method_11657(WATERLOGGED, false));
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 p_220053_2_, class_2338 p_220053_3_, class_3726 p_220053_4_) {
        return AllShapes.FLUID_VALVE.get(getPipeAxis(state));
    }

    @Override
    protected void method_9515(class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder.method_11667(ENABLED, WATERLOGGED));
    }

    @Override
    protected boolean prefersConnectionTo(class_4538 reader, class_2338 pos, class_2350 facing, boolean shaftAxis) {
        if (!shaftAxis) {
            class_2338 offset = pos.method_10093(facing);
            class_2680 blockState = reader.method_8320(offset);
            return FluidPipeBlock.canConnectTo(reader, offset, blockState, facing);
        }
        return super.prefersConnectionTo(reader, pos, facing, shaftAxis);
    }

    @NotNull
    public static class_2351 getPipeAxis(class_2680 state) {
        if (!(state.method_26204() instanceof FluidValveBlock))
            throw new IllegalStateException("Provided BlockState is for a different block.");
        class_2350 facing = state.method_11654(FACING);
        boolean alongFirst = !state.method_11654(AXIS_ALONG_FIRST_COORDINATE);
        for (class_2351 axis : Iterate.axes) {
            if (axis == facing.method_10166())
                continue;
            if (!alongFirst) {
                alongFirst = true;
                continue;
            }
            return axis;
        }
        throw new IllegalStateException("Impossible axis.");
    }

    @Override
    public class_2351 getAxis(class_2680 state) {
        return getPipeAxis(state);
    }

    @Override
    public void method_66388(class_2680 state, class_3218 world, class_2338 pos, boolean isMoving) {
        if (!world.field_9236)
            FluidPropagator.propagateChangedPipe(world, pos, state);
    }

    @Override
    public void method_9615(class_2680 state, class_1937 world, class_2338 pos, class_2680 oldState, boolean isMoving) {
        super.method_9615(state, world, pos, oldState, isMoving);
        if (world.field_9236)
            return;
        if (state != oldState)
            world.method_64311(pos, this, 1, class_1953.field_9310);
    }

    @Override
    public void neighborUpdate(class_2680 state, class_1937 world, class_2338 pos, class_2248 otherBlock, class_2338 neighborPos, boolean isMoving) {
        class_2350 d = FluidPropagator.validateNeighbourChange(state, world, pos, otherBlock, neighborPos, isMoving);
        if (d == null)
            return;
        if (!isOpenAt(state, d))
            return;
        world.method_64311(pos, this, 1, class_1953.field_9310);
    }

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 world,
        class_2338 pos,
        class_2248 otherBlock,
        @Nullable class_9904 wireOrientation,
        boolean isMoving
    ) {
        class_4209.method_19472(world, pos);
    }

    public static boolean isOpenAt(class_2680 state, class_2350 d) {
        return d.method_10166() == getPipeAxis(state);
    }

    @Override
    public void method_9588(class_2680 state, class_3218 world, class_2338 pos, class_5819 r) {
        FluidPropagator.propagateChangedPipe(world, pos, state);
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 pathComputationType) {
        return false;
    }

    @Override
    public Class<FluidValveBlockEntity> getBlockEntityClass() {
        return FluidValveBlockEntity.class;
    }

    @Override
    public class_2591<? extends FluidValveBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.FLUID_VALVE;
    }

    @Override
    public class_2680 method_9605(class_1750 context) {
        return withWater(super.method_9605(context), context);
    }

    @Override
    public class_2680 method_9559(
        class_2680 state,
        class_4538 world,
        class_10225 tickView,
        class_2338 pos,
        class_2350 direction,
        class_2338 neighbourPos,
        class_2680 neighbourState,
        class_5819 random
    ) {
        updateWater(world, tickView, state, pos);
        return state;
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return fluidState(state);
    }

}

==> create-fly-6.0.8-1.21.10-2-sources.jar: com/zurrtum/create/content/fluids/pipes/valve/FluidValveBlock.java <==
package com.zurrtum.create.content.fluids.pipes.valve;

import com.zurrtum.create.AllBlockEntityTypes;
import com.zurrtum.create.AllShapes;
import com.zurrtum.create.catnip.data.Iterate;
import com.zurrtum.create.content.fluids.FluidPropagator;
import com.zurrtum.create.content.fluids.pipes.FluidPipeBlock;
import com.zurrtum.create.content.fluids.pipes.IAxisPipe;
import com.zurrtum.create.content.kinetics.base.DirectionalAxisKineticBlock;
import com.zurrtum.create.foundation.block.IBE;
import com.zurrtum.create.foundation.block.NeighborUpdateListeningBlock;
import com.zurrtum.create.foundation.block.ProperWaterloggedBlock;
import net.minecraft.class_10;
import net.minecraft.class_10225;
import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_1937;
import net.minecraft.class_1953;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_2350.class_2351;
import net.minecraft.class_2591;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689.class_2690;
import net.minecraft.class_2746;
import net.minecraft.class_3218;
import net.minecraft.class_3610;
import net.minecraft.class_3726;
import net.minecraft.class_4538;
import net.minecraft.class_5819;
import net.minecraft.class_9904;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

public class FluidValveBlock extends DirectionalAxisKineticBlock implements IAxisPipe, IBE<FluidValveBlockEntity>, ProperWaterloggedBlock, NeighborUpdateListeningBlock {

    public static final class_2746 ENABLED = class_2746.method_11825("enabled");

    public FluidValveBlock(class_2251 properties) {
        super(properties);
        method_9590(method_9564().method_11657(ENABLED, false).method_11657(WATERLOGGED, false));
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 p_220053_2_, class_2338 p_220053_3_, class_3726 p_220053_4_) {
        return AllShapes.FLUID_VALVE.get(getPipeAxis(state));
    }

    @Override
    protected void method_9515(class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder.method_11667(ENABLED, WATERLOGGED));
    }

    @Override
    protected boolean prefersConnectionTo(class_4538 reader, class_2338 pos, class_2350 facing, boolean shaftAxis) {
        if (!shaftAxis) {
            class_2338 offset = pos.method_10093(facing);
            class_2680 blockState = reader.method_8320(offset);
            return FluidPipeBlock.canConnectTo(reader, offset, blockState, facing);
        }
        return super.prefersConnectionTo(reader, pos, facing, shaftAxis);
    }

    @NotNull
    public static class_2351 getPipeAxis(class_2680 state) {
        if (!(state.method_26204() instanceof FluidValveBlock))
            throw new IllegalStateException("Provided BlockState is for a different block.");
        class_2350 facing = state.method_11654(FACING);
        boolean alongFirst = !state.method_11654(AXIS_ALONG_FIRST_COORDINATE);
        for (class_2351 axis : Iterate.axes) {
            if (axis == facing.method_10166())
                continue;
            if (!alongFirst) {
                alongFirst = true;
                continue;
            }
            return axis;
        }
        throw new IllegalStateException("Impossible axis.");
    }

    @Override
    public class_2351 getAxis(class_2680 state) {
        return getPipeAxis(state);
    }

    @Override
    public void method_66388(class_2680 state, class_3218 world, class_2338 pos, boolean isMoving) {
        if (!world.method_8608())
            FluidPropagator.propagateChangedPipe(world, pos, state);
    }

    @Override
    public void method_9615(class_2680 state, class_1937 world, class_2338 pos, class_2680 oldState, boolean isMoving) {
        super.method_9615(state, world, pos, oldState, isMoving);
        if (world.method_8608())
            return;
        if (state != oldState)
            world.method_64311(pos, this, 1, class_1953.field_9310);
    }

    @Override
    public void neighborUpdate(class_2680 state, class_1937 world, class_2338 pos, class_2248 otherBlock, class_2338 neighborPos, boolean isMoving) {
        class_2350 d = FluidPropagator.validateNeighbourChange(state, world, pos, otherBlock, neighborPos, isMoving);
        if (d == null)
            return;
        if (!isOpenAt(state, d))
            return;
        world.method_64311(pos, this, 1, class_1953.field_9310);
    }

    @Override
    public void method_9612(
        class_2680 state,
        class_1937 world,
        class_2338 pos,
        class_2248 otherBlock,
        @Nullable class_9904 wireOrientation,
        boolean isMoving
    ) {
    }

    public static boolean isOpenAt(class_2680 state, class_2350 d) {
        return d.method_10166() == getPipeAxis(state);
    }

    @Override
    public void method_9588(class_2680 state, class_3218 world, class_2338 pos, class_5819 r) {
        FluidPropagator.propagateChangedPipe(world, pos, state);
    }

    @Override
    protected boolean method_9516(class_2680 state, class_10 pathComputationType) {
        return false;
    }

    @Override
    public Class<FluidValveBlockEntity> getBlockEntityClass() {
        return FluidValveBlockEntity.class;
    }

    @Override
    public class_2591<? extends FluidValveBlockEntity> getBlockEntityType() {
        return AllBlockEntityTypes.FLUID_VALVE;
    }

    @Override
    public class_2680 method_9605(class_1750 context) {
        return withWater(super.method_9605(context), context);
    }

    @Override
    public class_2680 method_9559(
        class_2680 state,
        class_4538 world,
        class_10225 tickView,
        class_2338 pos,
        class_2350 direction,
        class_2338 neighbourPos,
        class_2680 neighbourState,
        class_5819 random
    ) {
        updateWater(world, tickView, state, pos);
        return state;
    }

    @Override
    public class_3610 method_9545(class_2680 state) {
        return fluidState(state);
    }

}
